#!/bin/bash

# Packager: Filippo "NeverBorn" Mesirca (filippo.mesirca@gmail.com)
# Sources location : 
# - http://www.snort.org/dl/current/snort-2.4.4.tar.gz
# - http://snort.org/pub-bin/downloads.cgi/Download/vrt_pr/snortrules-pr-2.4.tar.gz

# program name/version
softversion='2.4.4'
softname='snort'
rulesver='2.4'

# architecture/package version
arch='i486'
cpu='i686'
packageversion='1z24'

# number of parallel jobs for make
ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
rm -f $package.*
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
snort: snort (version 2.4.4)
snort:
snort: Snort is an open source network intrusion detection and prevention
snort: system. It is capable of performing real-time traffic analysis,
snort: alerting, blocking and packet logging on IP networks. It utilizes a
snort: combination of protocol analysis and pattern matchingin order to
snort: detect a anomalies, misuse and attacks.Snort uses a flexible rules
snort: language to describe activity that can be consideredmalicious or
snort: anomalous as well as an analysis engine that incorporates a modular
snort: plugin architecture.
snort: Compiled for Zenwalk 2.4
EOF

# extract sources
srcdir="snort-$softversion"
cd $buildir
rm -rf $srcdir
tar zxvf $srcdir.tar.gz
cd $srcdir

# set correct permissions
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
 
# configure package for compilation
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
   --prefix=/usr \
   --sysconfdir=/etc/snort \
   --bindir=/usr/sbin \
   --localstatedir=/var \
   --enable-timestats \
   --enable-linux-smp-stats \
   --with-mysql=/usr \
   --program-prefix="" \
   --program-suffix=""
   
# compile package
make $ntasks

# install package to the target directory
make install DESTDIR=$dest

# copy the configuration files to $dest/etc/snort
mkdir -p $dest/etc/snort/rules
( cd etc/
  zcat $buildir/snort.conf.diff.gz | patch -p1
  cd $buildir/$srcdir
)
cp -a etc/classification.config $dest/etc/snort/classification.config.new
cp -a etc/gen-msg.map $dest/etc/snort/gen-msg.map.new
cp -a etc/generators $dest/etc/snort/generators.new
cp -a etc/reference.config $dest/etc/snort/reference.config.new
cp -a etc/sid $dest/etc/snort/sid.new
cp -a etc/sid-msg.map $dest/etc/snort/sid-msg.map.new
cp -a etc/snort.conf $dest/etc/snort/snort.conf.new
cp -a etc/threshold.conf $dest/etc/snort/threshold.conf.new
cp -a etc/unicode.map $dest/etc/snort/unicode.map.new

mkdir -p $dest/etc/rc.d
zcat $buildir/rc.snort.gz > $dest/etc/rc.d/rc.snort.new
chmod 644 $dest/etc/rc.d/rc.snort.new

# create the /var/log/snort directory
mkdir -p $dest/var/log/snort

# copy the doc files
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
   COPYING ChangeLog LICENSE RELEASE.NOTES doc/AUTHORS doc/BUGS doc/CREDITS doc/INSTALL doc/NEWS doc/PROBLEMS doc/README* doc/TODO doc/USAGE doc/WISHLIST doc/faq.pdf doc/snort_manual.pdf doc/snort_schema_v106.pdf \
   $dest/usr/doc/$softname-$softversion

# install the snort ruleset (unregistered user release)
( cd $dest/etc/snort
  tar zxvf $buildir/snortrules-pr-$rulesver.tar.gz
  rm -rf doc/
  cd rules
  for file in * ; do
    mv $file $file.new
  done
)
   
# strip executables 
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# gzip man pages
gzip -9 $dest/usr/man/*/*

# put the ZenWalk build and other needed files in the right directory
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion
cp -a $buildir/snort.conf.diff.gz $dest/usr/src/$softname-$softversion
cp -a $buildir/rc.snort.gz $dest/usr/src/$softname-$softversion
cp -a $buildir/doinst.sh.gz $dest/usr/src/$softname-$softversion
chown -R root.root $dest/usr/src/$softname-$softversion

# change files ownerships for the $dest/usr/bin and $dest/usr/sbin
chown -R root.bin $dest/usr/sbin

# make the package and move it to the build directory
zcat $buildir/doinst.sh.gz > $dest/install/doinst.sh
cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz $buildir

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5

if [ "$1" == "--cleanup" ]; then
  rm -rf $dest
  rm -rf $srcdir
fi
